@@ -11,8 +11,9 @@ import numpy as np
 import argparse
 import logging
 def run_it(params):
-    for wlt in range(0, 4):
-        Omega_0 = {'c': np.matrix([[wlt*10],
+    #test_me()
+    for wlt in range(0, 2):
+        Omega_0 = {'c': np.matrix([[wlt*80],
                                [0],
                                [10],
                                [3]
@@ -49,6 +50,11 @@ def main():
     parser.add_argument('--time_horizon', '-T', type=float, help='value like: T=2.2', required=True)
     parser.add_argument('--steps', '-N', type=int, help='value like N=4', required=True)
     parser.add_argument('--debug', '-deb', type=str, help='(y,n)', default='n', required=False)
+    parser.add_argument('--face_color', '-facol', type=str, help='name: orange, green or values', default='cyan', required=False)
+    parser.add_argument('--nx', '-nx', type=int, help='nx for meshgrid (integer)', default=6,
+                        required=False)
+    parser.add_argument('--ny', '-ny', type=int, help='ny for meshgrid (integer)', default=6,
+                        required=False)
     args = parser.parse_args()
     params = vars(args)
     if(params['debug']=='y'):
